Package: HSAUR3
Title: A Handbook of Statistical Analyses Using R (3rd Edition)
Date: 2024-08-17
Version: 1.0-15
Authors@R: c(person("Torsten", "Hothorn", role = c("aut", "cre"),
                 email = "Torsten.Hothorn@R-project.org", comment = c(ORCID = "0000-0001-8301-0471")),
          person(given = c("Brian", "S."),
                 family = "Everitt",
                 role = "aut"))
Maintainer: Torsten Hothorn <Torsten.Hothorn@R-project.org>
Description: Functions, data sets, analyses and examples from the 
  third edition of the book 
  ''A Handbook of Statistical Analyses Using R'' (Torsten Hothorn and Brian S.
  Everitt, Chapman & Hall/CRC, 2014). The first chapter
  of the book, which is entitled ''An Introduction to R'', 
  is completely included in this package, for all other chapters,
  a vignette containing all data analyses is available. In addition,
  Sweave source code for slides of selected chapters is included in 
  this package (see HSAUR3/inst/slides). The publishers web page is 
  '<https://www.routledge.com/A-Handbook-of-Statistical-Analyses-using-R/Hothorn-Everitt/p/book/9781482204582>'.
Depends: R (>= 3.0.0)
Suggests: boot (>= 1.3-9), lattice (>= 0.20-23), MASS (>= 7.3-29), mgcv
        (>= 1.7-27), rpart (>= 4.1-4), survival (>= 2.37-4), ape (>=
        3.0-11), coin (>= 1.1-3), flexmix (>= 2.3-11), Formula (>=
        1.1-1), gamair (>= 0.0.8), gamlss.data (>= 4.2.6), gee (>=
        4.13-18), KernSmooth (>= 2.23-10), lme4 (>= 1.0-5), maps (>=
        2.3-6), mboost (>= 2.2-3), mclust (>= 4.2), mlbench (>= 2.1-1),
        mice (>= 2.18), multcomp (>= 1.3-1), mvtnorm (>= 0.9-9996),
        partykit (>= 0.8-0), quantreg (>= 5.05), randomForest (>=
        4.6-7), rmeta (>= 2.16), sandwich (>= 2.3-0), scatterplot3d (>=
        0.3-34), sf (>= 1.0-9), sp (>= 1.0-14), TH.data (>= 1.0-2),
        tools, vcd (>= 1.3-1), wordcloud (>= 2.4), HSAUR2
LazyData: yes
License: GPL-2
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-08-17 16:31:15 UTC; hothorn
Author: Torsten Hothorn [aut, cre] (<https://orcid.org/0000-0001-8301-0471>),
  Brian S. Everitt [aut]
Repository: CRAN
Date/Publication: 2024-08-17 17:30:01 UTC
Built: R 4.6.0; ; 2026-04-25 17:11:29 UTC; unix
