\name{heptathlon}
\alias{heptathlon}
\docType{data}
\title{ Olympic Heptathlon Seoul 1988 }
\description{

    Results of the olympic heptathlon competition, Seoul, 1988.

}
\usage{data("heptathlon")}
\format{
  A data frame with 25 observations on the following 8 variables.
  \describe{
    \item{\code{hurdles}}{results 100m hurdles.}
    \item{\code{highjump}}{results high jump.}
    \item{\code{shot}}{results shot.}
    \item{\code{run200m}}{results 200m race.}
    \item{\code{longjump}}{results long jump.}
    \item{\code{javelin}}{results javelin.}
    \item{\code{run800m}}{results 800m race.}
    \item{\code{score}}{total score.}
  }
}
\details{

  The first combined Olympic event for women was the pentathlon,
  first held in Germany in 1928. Initially this consisted of the
  shot putt, long jump, 100m, high jump and javelin events held
  over two days. The pentathlon was first introduced into the Olympic
  Games in 1964, when it consisted of the 80m hurdles, shot, high
  jump, long jump and 200m. In 1977 the 200m was replaced by the
  800m and from 1981 the IAAF brought in the seven-event heptathlon
  in place of the pentathlon, with day one containing the events-100m
  hurdles, shot, high jump, 200m and day two, the long jump, javelin
  and 800m. A scoring system is used to assign points to the results
  from each event and the winner is the woman who accumulates the
  most points over the two days. The event made its first Olympic
  appearance in 1984.

  In the 1988 Olympics held in Seoul, the heptathlon was won
  by one of the stars of women's athletics in the USA, Jackie Joyner-Kersee.
  The results for all 25 competitors are given here.

}
\source{

  D. J. Hand, F. Daly, A. D. Lunn, K. J. McConway and E. Ostrowski (1994).
  \emph{A Handbook of Small Datasets}, Chapman and Hall/CRC, London.

}
\examples{

  data("heptathlon", package = "HSAUR3")
  plot(heptathlon)

}
\keyword{datasets}
